@@ -92,14 +92,14 @@ types are: YAML (http://yaml.org/) and JSON (http://json.org/).
 		}
 
 		if reportOptions.filters != nil {
-			var filterPaths []ytbx.Path
+			var filterPaths []*ytbx.Path
 			for _, pathString := range reportOptions.filters {
 				path, err := ytbx.ParsePathStringUnsafe(pathString)
 				if err != nil {
 					return wrap.Errorf(err, "failed to set path filter, because path %s cannot be parsed", pathString)
 				}
 
-				filterPaths = append(filterPaths, path)
+				filterPaths = append(filterPaths, &path)
 			}
 
 			report = report.Filter(filterPaths...)
