@@ -327,7 +327,6 @@ list:
 
 				result, err := compare(from, to)
 				Expect(err).To(BeNil())
-				Expect(result).NotTo(BeNil())
 				Expect(len(result)).To(BeEquivalentTo(0))
 			})
 		})
@@ -613,7 +612,6 @@ listY: [ Yo, Yo, Yo ]
 				)
 
 				Expect(err).To(BeNil())
-				Expect(results).NotTo(BeNil())
 				Expect(len(results)).To(BeEquivalentTo(0))
 			})
 
@@ -655,6 +653,14 @@ listY: [ Yo, Yo, Yo ]
 				}
 			})
 
+			It("should fail to compare files with different number of documents", func() {
+				from := ytbx.InputFile{Location: "/ginkgo/compare/test/from", Documents: multiDoc("foo: bar", "dead: beef")}
+				to := ytbx.InputFile{Location: "/ginkgo/compare/test/to", Documents: multiDoc("bar: foo")}
+
+				_, err := CompareInputFiles(from, to)
+				Expect(err).To(HaveOccurred())
+			})
+
 			It("should return differences in named lists even if no standard identifier is used", func() {
 				results, err := CompareInputFiles(
 					file("../../assets/prometheus/from.yml"),
@@ -893,5 +899,68 @@ b: bar
 				Expect(len(results.Diffs)).To(BeZero())
 			})
 		})
+
+		Context("input files containing Kubernetes resources", func() {
+			It("should return order change differences in YAML files with Kubernetes resources", func() {
+				from, to, err := ytbx.LoadFiles(assets("issues", "issue-184", "from.yml"), assets("issues", "issue-184", "to.yml"))
+				Expect(err).To(BeNil())
+				Expect(from).ToNot(BeNil())
+				Expect(to).ToNot(BeNil())
+
+				results, err := CompareInputFiles(from, to)
+				Expect(err).ToNot(HaveOccurred())
+				Expect(results).ToNot(BeNil())
+
+				Expect(len(results.Diffs)).To(BeEquivalentTo(1))
+			})
+
+			It("should report that a document was added", func() {
+				from := ytbx.InputFile{
+					Location: "/ginkgo/compare/test/from",
+					Documents: multiDoc(
+						`{"apiVersion": "apps/v1", "kind": "Deployment", "metadata": {"name": "x"}}`,
+					),
+				}
+
+				to := ytbx.InputFile{
+					Location: "/ginkgo/compare/test/to",
+					Documents: multiDoc(
+						`{"apiVersion": "apps/v1", "kind": "Deployment", "metadata": {"name": "x"}}`,
+						`{"apiVersion": "v1", "kind": "Service", "metadata": {"name": "y"}}`,
+					),
+				}
+
+				result, err := CompareInputFiles(from, to)
+				Expect(err).NotTo(HaveOccurred())
+
+				Expect(len(result.Diffs)).To(Equal(1))
+				Expect(len(result.Diffs[0].Details)).To(Equal(1))
+				Expect(result.Diffs[0].Details[0].Kind).To(Equal(ADDITION))
+			})
+
+			It("should report that a document was removed", func() {
+				from := ytbx.InputFile{
+					Location: "/ginkgo/compare/test/from",
+					Documents: multiDoc(
+						`{"apiVersion": "apps/v1", "kind": "Deployment", "metadata": {"name": "x"}}`,
+						`{"apiVersion": "v1", "kind": "Service", "metadata": {"name": "y"}}`,
+					),
+				}
+
+				to := ytbx.InputFile{
+					Location: "/ginkgo/compare/test/to",
+					Documents: multiDoc(
+						`{"apiVersion": "apps/v1", "kind": "Deployment", "metadata": {"name": "x"}}`,
+					),
+				}
+
+				result, err := CompareInputFiles(from, to)
+				Expect(err).NotTo(HaveOccurred())
+
+				Expect(len(result.Diffs)).To(Equal(1))
+				Expect(len(result.Diffs[0].Details)).To(Equal(1))
+				Expect(result.Diffs[0].Details[0].Kind).To(Equal(REMOVAL))
+			})
+		})
 	})
 })
